summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/history/historylogger.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/plugins/history/historylogger.h')
-rw-r--r--kopete/plugins/history/historylogger.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/kopete/plugins/history/historylogger.h b/kopete/plugins/history/historylogger.h
index 85cdbdd7..49e368d9 100644
--- a/kopete/plugins/history/historylogger.h
+++ b/kopete/plugins/history/historylogger.h
@@ -17,7 +17,7 @@
#ifndef HISTORYLOGGER_H
#define HISTORYLOGGER_H
-#include <qobject.h>
+#include <tqobject.h>
#include "kopetemessage.h" //TODO: REMOVE
namespace Kopete { class Contact; }
@@ -46,8 +46,8 @@ public:
/**
* Constructor, takes the contact, and the color of messages
*/
- HistoryLogger( Kopete::MetaContact *m , QObject *parent = 0, const char *name = 0);
- HistoryLogger( Kopete::Contact *c , QObject *parent = 0, const char *name = 0);
+ HistoryLogger( Kopete::MetaContact *m , TQObject *parent = 0, const char *name = 0);
+ HistoryLogger( Kopete::Contact *c , TQObject *parent = 0, const char *name = 0);
~HistoryLogger();
@@ -62,10 +62,10 @@ public:
* set a searching filter
* @param filter is the string to search
* @param caseSensitive say if the case is important
- * @param isRegExp say if the filter is a QRegExp, or a simle string
+ * @param isRegExp say if the filter is a TQRegExp, or a simle string
*/
- void setFilter(const QString& filter, bool caseSensitive=false , bool isRegExp=false);
- QString filter() const;
+ void setFilter(const TQString& filter, bool caseSensitive=false , bool isRegExp=false);
+ TQString filter() const;
bool filterCaseSensitive() const ;
bool filterRegExp() const;
@@ -83,7 +83,7 @@ public:
* read @param lines message from the current position
* from Kopete::Contact @param c in the given @param sens
*/
- QValueList<Kopete::Message> readMessages(unsigned int lines,
+ TQValueList<Kopete::Message> readMessages(unsigned int lines,
const Kopete::Contact *c=0, Sens sens=Default,
bool reverseOrder=false, bool colorize=true);
@@ -92,7 +92,7 @@ public:
* because its structure is really different.
* Read all the messages for the given @param date
*/
- QValueList<Kopete::Message> readMessages(QDate date);
+ TQValueList<Kopete::Message> readMessages(TQDate date);
/**
@@ -113,40 +113,40 @@ public:
/**
* @return The list of the days for which there is a log for m_metaContact for month of * @param date (don't care of the day)
*/
- QValueList<int> getDaysForMonth(QDate date);
+ TQValueList<int> getDaysForMonth(TQDate date);
/**
* Get the filename of the xml file which contains the history from the
* contact in the specified @param date. Specify @param date in order to get the filename for
* the given date.year() date.month().
*/
- static QString getFileName(const Kopete::Contact* , QDate date);
+ static TQString getFileName(const Kopete::Contact* , TQDate date);
private:
bool m_hideOutgoing;
bool m_filterCaseSensitive;
bool m_filterRegExp;
- QString m_filter;
+ TQString m_filter;
/*
*contais all QDomDocument, for a KC, for a specified Month
*/
- QMap<const Kopete::Contact*,QMap<unsigned int , QDomDocument> > m_documents;
+ TQMap<const Kopete::Contact*,TQMap<unsigned int , TQDomDocument> > m_documents;
/**
* Contains the current message.
* in fact, this is the next, still not showed
*/
- QMap<const Kopete::Contact*, QDomElement> m_currentElements;
+ TQMap<const Kopete::Contact*, TQDomElement> m_currentElements;
/**
* Get the document, open it is @param canload is true, contain is set to false if the document
* is not already contained
*/
- QDomDocument getDocument(const Kopete::Contact *c, unsigned int month , bool canLoad=true , bool* contain=0L);
+ TQDomDocument getDocument(const Kopete::Contact *c, unsigned int month , bool canLoad=true , bool* contain=0L);
- QDomDocument getDocument(const Kopete::Contact *c, const QDate date, bool canLoad=true, bool* contain=0L);
+ TQDomDocument getDocument(const Kopete::Contact *c, const TQDate date, bool canLoad=true, bool* contain=0L);
/**
* look over files to get the last month for this contact
@@ -175,16 +175,16 @@ private:
/*
* keep the old position in memory, so if we change the sens, we can begin here
*/
- QMap<const Kopete::Contact*, QDomElement> m_oldElements;
+ TQMap<const Kopete::Contact*, TQDomElement> m_oldElements;
unsigned int m_oldMonth;
Sens m_oldSens;
/**
* the timer used to save the file
*/
- QTimer *m_saveTimer;
- QDomDocument m_toSaveDocument;
- QString m_toSaveFileName;
+ TQTimer *m_saveTimer;
+ TQDomDocument m_toSaveDocument;
+ TQString m_toSaveFileName;
unsigned int m_saveTimerTime; //time in ms between each save
/**
@@ -199,7 +199,7 @@ private:
* due to a bug in QT, i have to keep the document element in the memory to
* prevent crashes
*/
- QValueList<QDomElement> workaround;
+ TQValueList<TQDomElement> workaround;
private slots:
/**
@@ -113,40 +113,40 @@ public:
/*
- *contais all QDomDocument, for a KC, for a specified Month
+ *contais all TQDomDocument, for a KC, for a specified Month
*/